(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/material'), require('@angular/common'), require('@angular/flex-layout')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', '@angular/material', '@angular/common', '@angular/flex-layout'], factory) :
	(factory((global.ng = global.ng || {}, global.ng['time-picker'] = {}),global.ng.core,global.material,global.common,global.flexLayout));
}(this, (function (exports,core,material,common,flexLayout) { 'use strict';

// Current type to show
// Current type to show

// Current type to show
(function (CLOCK_TYPE) {
    CLOCK_TYPE[CLOCK_TYPE["HOURS"] = 1] = "HOURS";
    CLOCK_TYPE[CLOCK_TYPE["MINUTES"] = 2] = "MINUTES";
})(exports.CLOCK_TYPE || (exports.CLOCK_TYPE = {}));

var WClockComponent = /** @class */ (function () {
    function WClockComponent() {
        this.userTimeChange = new core.EventEmitter();
        this.viewChange = new core.EventEmitter();
        this.steps = new Array();
    }
    WClockComponent.prototype.ngOnChanges = function () {
        this.setupUI();
    };
    WClockComponent.prototype.setupUI = function () {
        this.steps = new Array();
        switch (this.currentView) {
            case exports.CLOCK_TYPE.HOURS:
                for (var i = 1; i <= this.userTime.format; i++) {
                    this.steps.push(i);
                    this.selectedTimePart = this.userTime.hour || 0;
                    if (this.selectedTimePart > this.userTime.format) {
                        this.selectedTimePart -= this.userTime.format;
                    }
                }
                break;
            case exports.CLOCK_TYPE.MINUTES:
                for (var i = 5; i <= 55; i += 5) {
                    this.steps.push(i);
                }
                this.steps.push(0);
                this.selectedTimePart = this.userTime.minute || 0;
                break;
        }
    };
    WClockComponent.prototype.getPointerStyle = function () {
        var divider = 1;
        switch (this.currentView) {
            case exports.CLOCK_TYPE.HOURS:
                divider = this.userTime.format;
                break;
            case exports.CLOCK_TYPE.MINUTES:
                divider = 60;
                break;
        }
        var degrees = 0;
        if (this.currentView === exports.CLOCK_TYPE.HOURS) {
            degrees = Math.round(this.userTime.hour * (360 / divider)) - 180;
        }
        else {
            degrees = Math.round(this.userTime.minute * (360 / divider)) - 180;
        }
        var style = {
            '-webkit-transform': 'rotate(' + degrees + 'deg)',
            '-ms-transform': 'rotate(' + degrees + 'deg)',
            'transform': 'rotate(' + degrees + 'deg)'
        };
        return style;
    };
    WClockComponent.prototype.getTimeValueClass = function (step, index) {
        if (this.currentView === exports.CLOCK_TYPE.HOURS) {
            this.STEP_DEG = 360 / this.userTime.format;
        }
        else {
            this.STEP_DEG = 360 / 12;
        }
        var classes = 'w-clock-step w-clock-deg' + (this.STEP_DEG * (index + 1));
        if (this.selectedTimePart === step) {
            classes += ' mat-primary';
        }
        return classes;
    };
    WClockComponent.prototype.changeTimeValue = function (step) {
        if (this.currentView === exports.CLOCK_TYPE.HOURS) {
            this.userTime.hour = step;
            // auto switch to minutes
            this.viewChange.emit(exports.CLOCK_TYPE.MINUTES);
        }
        else {
            this.userTime.minute = step;
            // auto switch to hours
            this.viewChange.emit(exports.CLOCK_TYPE.HOURS);
        }
        this.userTimeChange.emit(this.userTime);
    };
    WClockComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'w-clock',
                    styleUrls: ['./w-clock.component.scss'],
                    templateUrl: './w-clock.component.html'
                },] },
    ];
    /** @nocollapse */
    WClockComponent.ctorParameters = function () { return []; };
    WClockComponent.propDecorators = {
        "userTime": [{ type: core.Input },],
        "userTimeChange": [{ type: core.Output },],
        "currentView": [{ type: core.Input },],
        "viewChange": [{ type: core.Output },],
        "color": [{ type: core.Input },],
    };
    return WClockComponent;
}());

var WTimeDialogComponent = /** @class */ (function () {
    function WTimeDialogComponent(
    //@Inject(MAT_DIALOG_DATA) private data: { time: ITime, color: string },
    data, color, dialogRef) {
        this.data = data;
        this.color = color;
        this.dialogRef = dialogRef;
        this.VIEW_HOURS = exports.CLOCK_TYPE.HOURS;
        this.VIEW_MINUTES = exports.CLOCK_TYPE.MINUTES;
        this.currentView = this.VIEW_HOURS;
        this.userTime = data.time;
        this.color = data.color;
        console.log('this.color', this.color);
    }
    WTimeDialogComponent.prototype.revert = function () {
        this.dialogRef.close(-1);
    };
    WTimeDialogComponent.prototype.submit = function () {
        this.dialogRef.close(this.userTime);
    };
    WTimeDialogComponent.decorators = [
        { type: core.Component, args: [{
                    styleUrls: ['./w-time-dialog.component.scss'],
                    templateUrl: './w-time-dialog.component.html'
                },] },
    ];
    /** @nocollapse */
    WTimeDialogComponent.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: core.Inject, args: [material.MAT_DIALOG_DATA,] },] },
        { type: undefined, decorators: [{ type: core.Inject, args: [material.MAT_DIALOG_DATA,] },] },
        { type: material.MatDialogRef, },
    ]; };
    return WTimeDialogComponent;
}());

var WMatTimePickerComponent = /** @class */ (function () {
    function WMatTimePickerComponent(dialog) {
        this.dialog = dialog;
        this.userTimeChange = new core.EventEmitter();
    }
    WMatTimePickerComponent.prototype.ngOnInit = function () {
        if (!this.userTime) {
            this.userTime = {
                hour: 10,
                minute: 25,
                meriden: 'PM',
                format: 24
            };
        }
    };
    Object.defineProperty(WMatTimePickerComponent.prototype, "time", {
        get: function () {
            if (!this.userTime) {
                return '';
            }
            var meriden = "" + this.userTime.meriden;
            if (this.userTime.format === 24) {
                meriden = '';
            }
            var hour = "" + this.userTime.hour;
            if (this.userTime.hour === 24) {
                hour = '00';
            }
            if (this.userTime.minute === 0) {
                return hour + ":00 " + meriden;
            }
            else if (this.userTime.minute < 10) {
                var tt = '0' + String(this.userTime.minute);
                return hour + ":" + tt + " " + meriden;
            }
            else {
                return hour + ":" + this.userTime.minute + " " + meriden;
            }
        },
        enumerable: true,
        configurable: true
    });
    WMatTimePickerComponent.prototype.showPicker = function ($event) {
        var _this = this;
        var dialogRef = this.dialog.open(WTimeDialogComponent, {
            data: {
                time: {
                    hour: this.userTime.hour,
                    minute: this.userTime.minute,
                    meriden: this.userTime.meriden,
                    format: this.userTime.format
                },
                color: this.color
            }
        });
        dialogRef.afterClosed()
            .subscribe(function (result) {
            // result will be update userTime object or -1 or undefined (closed dialog w/o clicking cancel)
            // result will be update userTime object or -1 or undefined (closed dialog w/o clicking cancel)
            if (result === undefined) {
                return;
            }
            else if (result !== -1) {
                _this.userTime = result;
                _this.emituserTimeChange();
            }
        });
        return false;
    };
    WMatTimePickerComponent.prototype.emituserTimeChange = function () {
        this.userTimeChange.emit(this.userTime);
    };
    WMatTimePickerComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'w-mat-timepicker',
                    styleUrls: ['./w-mat-timepicker.component.scss'],
                    templateUrl: './w-mat-timepicker.component.html'
                },] },
    ];
    /** @nocollapse */
    WMatTimePickerComponent.ctorParameters = function () { return [
        { type: material.MatDialog, },
    ]; };
    WMatTimePickerComponent.propDecorators = {
        "userTime": [{ type: core.Input },],
        "userTimeChange": [{ type: core.Output },],
        "color": [{ type: core.Input },],
    };
    return WMatTimePickerComponent;
}());

var WTimeComponent = /** @class */ (function () {
    function WTimeComponent() {
        this.userTimeChange = new core.EventEmitter();
        this.onRevert = new core.EventEmitter();
        this.onSubmit = new core.EventEmitter();
        this.VIEW_HOURS = exports.CLOCK_TYPE.HOURS;
        this.VIEW_MINUTES = exports.CLOCK_TYPE.MINUTES;
        this.currentView = this.VIEW_HOURS;
    }
    WTimeComponent.prototype.ngOnInit = function () {
        if (!this.userTime) {
            this.userTime = {
                hour: 6,
                minute: 0,
                meriden: 'PM',
                format: 12
            };
        }
        if (!this.revertLabel) {
            this.revertLabel = 'Cancel';
        }
        if (!this.submitLabel) {
            this.submitLabel = 'OK';
        }
    };
    WTimeComponent.prototype.formatHour = function () {
        if (this.userTime.format === 24) {
            if (this.userTime.hour === 24) {
                return '00';
            }
            else if (this.userTime.hour < 10) {
                return '0' + String(this.userTime.hour);
            }
        }
        return String(this.userTime.hour);
    };
    WTimeComponent.prototype.formatMinute = function () {
        if (this.userTime.minute === 0) {
            return '00';
        }
        else if (this.userTime.minute < 10) {
            return '0' + String(this.userTime.minute);
        }
        else {
            return String(this.userTime.minute);
        }
    };
    WTimeComponent.prototype.setCurrentView = function (type) {
        this.currentView = type;
    };
    WTimeComponent.prototype.setMeridien = function (m) {
        this.userTime.meriden = m;
    };
    WTimeComponent.prototype.revert = function () {
        this.onRevert.emit();
    };
    WTimeComponent.prototype.submit = function () {
        this.onSubmit.emit(this.userTime);
    };
    WTimeComponent.prototype.emituserTimeChange = function (event) {
        this.userTimeChange.emit(this.userTime);
    };
    WTimeComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'w-time',
                    templateUrl: './w-time.component.html',
                    styleUrls: ['./w-time.component.scss']
                },] },
    ];
    /** @nocollapse */
    WTimeComponent.ctorParameters = function () { return []; };
    WTimeComponent.propDecorators = {
        "userTime": [{ type: core.Input },],
        "userTimeChange": [{ type: core.Output },],
        "revertLabel": [{ type: core.Input },],
        "submitLabel": [{ type: core.Input },],
        "onRevert": [{ type: core.Output },],
        "onSubmit": [{ type: core.Output },],
        "color": [{ type: core.Input },],
    };
    return WTimeComponent;
}());

var Angular5TimePickerModule = /** @class */ (function () {
    function Angular5TimePickerModule() {
    }
    Angular5TimePickerModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [
                        WMatTimePickerComponent,
                        WTimeDialogComponent,
                        WClockComponent,
                        WTimeComponent,
                    ],
                    imports: [
                        material.MatButtonModule,
                        material.MatButtonToggleModule,
                        material.MatDialogModule,
                        material.MatFormFieldModule,
                        material.MatIconModule,
                        material.MatInputModule,
                        material.MatSelectModule,
                        material.MatToolbarModule,
                        common.CommonModule,
                        flexLayout.FlexLayoutModule,
                    ],
                    exports: [
                        WMatTimePickerComponent,
                        WTimeDialogComponent,
                        WClockComponent,
                        WTimeComponent,
                    ],
                    entryComponents: [
                        WMatTimePickerComponent,
                        WTimeDialogComponent,
                        WClockComponent,
                        WTimeComponent,
                    ]
                },] },
    ];
    /** @nocollapse */
    Angular5TimePickerModule.ctorParameters = function () { return []; };
    return Angular5TimePickerModule;
}());

exports.Angular5TimePickerModule = Angular5TimePickerModule;
exports.WMatTimePickerComponent = WMatTimePickerComponent;
exports.WTimeDialogComponent = WTimeDialogComponent;
exports.WClockComponent = WClockComponent;
exports.WTimeComponent = WTimeComponent;

Object.defineProperty(exports, '__esModule', { value: true });

})));
